@@ -2,7 +2,7 @@
   mairix - message index builder and finder for maildir folders.
 
  **********************************************************************
- * Copyright (C) Richard P. Curnow  2002,2003,2004,2005
+ * Copyright (C) Richard P. Curnow  2002,2003,2004,2005,2006
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  **********************************************************************
  */
@@ -179,6 +179,7 @@ static int char_length(struct database *db)/*{{{*/
       case MTY_MBOX:
         break;
       case MTY_FILE:
+      case MTY_IMAP:
         assert(db->msgs[i].src.mpf.path);
         result += (1 + strlen(db->msgs[i].src.mpf.path));
         break;
@@ -322,6 +323,9 @@ static char *write_type_and_flag_table(struct database *db, unsigned int *uidata
       case MTY_DEAD:
         cdata[i] = DB_MSG_DEAD;
         break;
+      case MTY_IMAP:
+        cdata[i] = DB_MSG_IMAP;
+        break;
     }
 
     if (msgdata->seen)    cdata[i] |= FLAG_SEEN;
@@ -350,6 +354,14 @@ static char *write_messages(struct database *db, struct write_map *map, unsigned
         memcpy(cdata, db->msgs[i].src.mpf.path, 1 + slen); /* include trailing null */
         cdata += (1 + slen);
         break;
+      case MTY_IMAP:
+        slen = strlen(db->msgs[i].src.mpf.path);
+        uidata[map->path_offset + i] = cdata - data;
+        uidata[map->date_offset + i] = db->msgs[i].date;
+        uidata[map->tid_offset + i]  = db->msgs[i].tid;
+        memcpy(cdata, db->msgs[i].src.mpf.path, 1 + slen); /* include trailing null */
+        cdata += (1 + slen);
+        break;
       case MTY_MBOX:
         {
           int mbno = db->msgs[i].src.mbox.file_index;
@@ -374,7 +386,7 @@ static char *write_messages(struct database *db, struct write_map *map, unsigned
     }
   }
   if (verbose) {
-    printf("Wrote %d messages (%d bytes tables, %d bytes text)\n",
+    printf("Wrote %d messages (%d bytes of tables, %d bytes of text)\n",
            db->n_msgs, 4*5*db->n_msgs, (int)(cdata - start_cdata));
   }
   return cdata; /* new value */
@@ -410,7 +422,7 @@ static  char *write_mbox_headers(struct database *db, struct write_map *map, uns
     }
   }
   if (verbose) {
-    printf("Wrote %d mbox headers (%d bytes tables, %d bytes paths)\n",
+    printf("Wrote %d mbox headers (%d bytes of tables, %d bytes of paths)\n",
         db->n_mboxen, 4*4*db->n_mboxen, (int)(cdata - start_cdata));
   }
   return cdata;
@@ -485,7 +497,7 @@ static char *write_toktable(struct toktable *tab, struct write_map_toktable *map
   }
 
   if (verbose) {
-    printf("%s: Wrote %d tokens (%d bytes tables, %d bytes of text, %d bytes of hit encoding)\n",
+    printf("%s: Wrote %d tokens (%d bytes of tables, %d bytes of text, %d bytes of hit encoding)\n",
             header_name, n, 2*4*n, (int)(mid_cdata - start_cdata), (int)(cdata - mid_cdata));
   }
 
@@ -550,7 +562,7 @@ static char *write_toktable2(struct toktable2 *tab, struct write_map_toktable2 *
   }
 
   if (verbose) {
-    printf("%s: Wrote %d tokens (%d bytes tables, %d bytes of text, %d bytes of hit encoding)\n",
+    printf("%s: Wrote %d tokens (%d bytes of tables, %d bytes of text, %d bytes of hit encoding)\n",
             header_name, n, 2*4*n, (int)(mid_cdata - start_cdata), (int)(cdata - mid_cdata));
   }
 
